@@ -203,6 +203,9 @@
 #undef SKALIBS_HASCHROOT
 #define SKALIBS_HASCHROOT
 
+#undef SKALIBS_HASCLONENEWPID
+#define SKALIBS_HASCLONENEWPID
+
 #undef SKALIBS_HASPOSIXSPAWNSETSID
 #define SKALIBS_HASPOSIXSPAWNSETSID
 
